# Pick Place 3D
## Python package
A package for pick and place using 3D data from stereo cameras. 

## Hardware requirements
Pick and place is performed using urx which is for use with Universal Robots

## Software requirements